==> wire-schema-jvm-4.8.1-javadoc.jar: wire-schema/com.squareup.wire.schema/-target/index.md <==
//[wire-schema](../../../index.md)/[com.squareup.wire.schema](../index.md)/[Target](index.md)

# Target

[common]\
abstract class [Target](index.md) : [Serializable](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.io/-serializable/index.html)

## Functions

| Name | Summary |
|---|---|
| [copyTarget](copy-target.md) | [common]<br>abstract fun [copyTarget](copy-target.md)(includes: [List](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-list/index.html)&lt;[String](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)&gt; = this.includes, excludes: [List](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-list/index.html)&lt;[String](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)&gt; = this.excludes, exclusive: [Boolean](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html) = this.exclusive, outDirectory: [String](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html) = this.outDirectory): [Target](index.md)<br>Returns a new Target object that is a copy of this one, but with the given fields updated. |
| [newHandler](new-handler.md) | [common]<br>abstract fun [newHandler](new-handler.md)(): [SchemaHandler](../-schema-handler/index.md) |

## Properties

| Name | Summary |
|---|---|
| [excludes](excludes.md) | [common]<br>abstract val [excludes](excludes.md): [List](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-list/index.html)&lt;[String](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)&gt;<br>Proto types to excluded generated sources for. Types listed here will not be generated for this target. |
| [exclusive](exclusive.md) | [common]<br>abstract val [exclusive](exclusive.md): [Boolean](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html)<br>True if types emitted for this target should not also be emitted for other targets. Use this to cause multiple outputs to be emitted for the same input type. |
| [includes](includes.md) | [common]<br>abstract val [includes](includes.md): [List](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-list/index.html)&lt;[String](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)&gt;<br>Proto types to include generated sources for. Types listed here will be generated for this target and not for subsequent targets in the task. |
| [outDirectory](out-directory.md) | [common]<br>abstract val [outDirectory](out-directory.md): [String](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)<br>Directory where this target will write its output. |

==> wire-schema-jvm-4.9.1-javadoc.jar: wire-schema/com.squareup.wire.schema/-target/index.md <==
//[wire-schema](../../../index.md)/[com.squareup.wire.schema](../index.md)/[Target](index.md)

# Target

[common]\
abstract class [Target](index.md) : Serializable

## Constructors

| | |
|---|---|
| [Target](-target.md) | [common]<br>constructor() |

## Properties

| Name | Summary |
|---|---|
| [excludes](excludes.md) | [common]<br>abstract val [excludes](excludes.md): [List](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-list/index.html)&lt;[String](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)&gt;<br>Proto types to excluded generated sources for. Types listed here will not be generated for this target. |
| [exclusive](exclusive.md) | [common]<br>abstract val [exclusive](exclusive.md): [Boolean](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html)<br>True if types emitted for this target should not also be emitted for other targets. Use this to cause multiple outputs to be emitted for the same input type. |
| [includes](includes.md) | [common]<br>abstract val [includes](includes.md): [List](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-list/index.html)&lt;[String](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)&gt;<br>Proto types to include generated sources for. Types listed here will be generated for this target and not for subsequent targets in the task. |
| [outDirectory](out-directory.md) | [common]<br>abstract val [outDirectory](out-directory.md): [String](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)<br>Directory where this target will write its output. |

## Functions

| Name | Summary |
|---|---|
| [copyTarget](copy-target.md) | [common]<br>abstract fun [copyTarget](copy-target.md)(includes: [List](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-list/index.html)&lt;[String](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)&gt; = this.includes, excludes: [List](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-list/index.html)&lt;[String](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)&gt; = this.excludes, exclusive: [Boolean](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html) = this.exclusive, outDirectory: [String](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html) = this.outDirectory): [Target](index.md)<br>Returns a new Target object that is a copy of this one, but with the given fields updated. |
| [newHandler](new-handler.md) | [common]<br>abstract fun [newHandler](new-handler.md)(): [SchemaHandler](../-schema-handler/index.md) |
